@@ -1,6 +1,6 @@
 // ddlineedit.h
 
-// Copyright (C) 2012-2015 by Werner Lemberg.
+// Copyright (C) 2012-2017 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -11,13 +11,16 @@
 // with the ttfautohint library.
 
 
-#ifndef __DDLINEEDIT_H__
-#define __DDLINEEDIT_H__
+#ifndef DDLINEEDIT_H_
+#define DDLINEEDIT_H_
 
 #include <config.h>
 #include "ttlineedit.h"
 
-#include <QtGui>
+#include <QDragEnterEvent>
+#include <QFileInfo>
+#include <QMimeData>
+#include <QUrl>
 
 enum Drag_Drop_File_Type
 {
@@ -42,6 +45,6 @@ public:
 };
 
 
-#endif // __DDLINEEDIT_H__
+#endif // DDLINEEDIT_H_
 
 // end of ddlineedit.h
