@@ -85,7 +85,7 @@ const Tag_Names feature_names[] =
 //   d: &Dehint
 //   e: Control Instructions Fil&e
 //   f: &File (menu)
-//   g: Stron&g Stem Width and Positioning
+//   g: Stem Width and Positionin&g Mode
 //   h: &Help (menu)
 //   i: &Input Font
 //   j: Ad&just Subglyphs
@@ -111,9 +111,9 @@ Main_GUI::Main_GUI(bool horizontal_layout,
                    int range_min,
                    int range_max,
                    int limit,
-                   bool gray,
-                   bool gdi,
-                   bool dw,
+                   int gray,
+                   int gdi,
+                   int dw,
                    int increase,
                    const char* exceptions,
                    int stem_width,
@@ -133,9 +133,9 @@ Main_GUI::Main_GUI(bool horizontal_layout,
 : hinting_range_min(range_min),
   hinting_range_max(range_max),
   hinting_limit(limit),
-  gray_strong_stem_width(gray),
-  gdi_cleartype_strong_stem_width(gdi),
-  dw_cleartype_strong_stem_width(dw),
+  gray_stem_width_mode(gray),
+  gdi_cleartype_stem_width_mode(gdi),
+  dw_cleartype_stem_width_mode(dw),
   increase_x_height(increase),
   x_height_snapping_exceptions_string(exceptions),
   fallback_stem_width(stem_width),
@@ -397,8 +397,12 @@ Main_GUI::check_dehint()
     ref_idx_box->setEnabled(false);
 
     stem_label->setEnabled(false);
+
+    gray_label->setEnabled(false);
     gray_box->setEnabled(false);
+    gdi_label->setEnabled(false);
     gdi_box->setEnabled(false);
+    dw_label->setEnabled(false);
     dw_box->setEnabled(false);
   }
   else
@@ -444,8 +448,12 @@ Main_GUI::check_dehint()
     ref_idx_box->setEnabled(true);
 
     stem_label->setEnabled(true);
+
+    gray_label->setEnabled(true);
     gray_box->setEnabled(true);
+    gdi_label->setEnabled(true);
     gdi_box->setEnabled(true);
+    dw_label->setEnabled(true);
     dw_box->setEnabled(true);
   }
 }
@@ -1261,9 +1269,10 @@ again:
                             ? 0
                             : limit_box->value();
 
-  info_data.gray_strong_stem_width = gray_box->isChecked();
-  info_data.gdi_cleartype_strong_stem_width = gdi_box->isChecked();
-  info_data.dw_cleartype_strong_stem_width = dw_box->isChecked();
+  // indices 0, 1, 2 are mapped to values -1, 0, 1
+  info_data.gray_stem_width_mode = gray_box->currentIndex() - 1;
+  info_data.gdi_cleartype_stem_width_mode = gdi_box->currentIndex() - 1;
+  info_data.dw_cleartype_stem_width_mode = dw_box->currentIndex() - 1;
 
   info_data.increase_x_height = no_x_increase_box->isChecked()
                                 ? 0
@@ -1340,9 +1349,9 @@ again:
                  "reference-index, reference-name,"
                  "hinting-range-min, hinting-range-max,"
                  "hinting-limit,"
-                 "gray-strong-stem-width,"
-                 "gdi-cleartype-strong-stem-width,"
-                 "dw-cleartype-strong-stem-width,"
+                 "gray-stem-width-mode,"
+                 "gdi-cleartype-stem-width-mode,"
+                 "dw-cleartype-stem-width-mode,"
                  "progress-callback, progress-callback-data,"
                  "error-callback, error-callback-data,"
                  "info-callback, info-post-callback, info-callback-data,"
@@ -1359,9 +1368,9 @@ again:
                  info_data.reference_index, info_data.reference_name,
                  info_data.hinting_range_min, info_data.hinting_range_max,
                  info_data.hinting_limit,
-                 info_data.gray_strong_stem_width,
-                 info_data.gdi_cleartype_strong_stem_width,
-                 info_data.dw_cleartype_strong_stem_width,
+                 info_data.gray_stem_width_mode,
+                 info_data.gdi_cleartype_stem_width_mode,
+                 info_data.dw_cleartype_stem_width_mode,
                  gui_progress, &gui_progress_data,
                  gui_error, &gui_error_data,
                  info_func, info_post_func, &info_data,
@@ -1477,6 +1486,11 @@ Main_GUI::create_layout(bool horizontal_layout)
        "&nbsp;&nbsp;<i>feature</i>"
        "&nbsp;&nbsp;<tt>@</tt>&nbsp;<i>glyph&#8209;ids</i><br>"
 
+       "&nbsp;&nbsp;[&nbsp;<i>subfont&#8209;idx</i>&nbsp;]"
+       "&nbsp;&nbsp;<i>script</i>"
+       "&nbsp;&nbsp;<i>feature</i>"
+       "&nbsp;&nbsp;<tt>width</tt>&nbsp;<i>stem&#8209;widths</i><br>"
+
        "&nbsp;&nbsp;[&nbsp;<i>subfont&#8209;idx</i>&nbsp;]"
        "&nbsp;&nbsp;<i>glyph&#8209;id</i>"
        "&nbsp;&nbsp;<tt>left</tt>&nbsp;|&nbsp;<tt>right</tt>&nbsp;<i>points</i>"
@@ -1507,6 +1521,11 @@ Main_GUI::create_layout(bool horizontal_layout)
        " <i>glyph&#8209;id</i> values and value ranges.<br>"
        "&nbsp;<br>"
 
+       "<i>stem&#8209;widths</i> is a comma-separated list of integer"
+       " stem widths (in font units); the first value sets the default stem"
+       " width.<br>"
+       "&nbsp;<br>"
+
        "<tt>left</tt> (<tt>right</tt>) creates one-point segments"
        " with direction left (right), possibly having a width (in font units)"
        " given by <i>left&#8209;offset</i> and <i>right&#8209;offset</i>"
@@ -1532,10 +1551,10 @@ Main_GUI::create_layout(bool horizontal_layout)
        " and ppem values as with x&nbsp;height snapping exceptions.<br>"
 
        "Keywords <tt>left</tt>, <tt>right</tt>, <tt>nodir</tt>,"
-       " <tt>point</tt>, <tt>touch</tt>, <tt>xshift</tt>, and"
-       " <tt>yshift</tt> can be abbreviated as <tt>l</tt>, <tt>r</tt>,"
-       " <tt>n</tt>, <tt>p</tt>, <tt>t</tt>, <tt>x</tt>, and <tt>y</tt>,"
-       " respectively.<br>"
+       " <tt>point</tt>, <tt>touch</tt>, <tt>width</tt>, <tt>xshift</tt>,"
+       " and <tt>yshift</tt> can be abbreviated as <tt>l</tt>, <tt>r</tt>,"
+       " <tt>n</tt>, <tt>p</tt>, <tt>t</tt>, <tt>w</tt>, <tt>x</tt>, and"
+       " <tt>y</tt>, respectively.<br>"
 
        "Control instruction entries are separated"
        " by character&nbsp;<tt>;</tt> or by a newline.<br>"
@@ -1822,29 +1841,45 @@ Main_GUI::create_layout(bool horizontal_layout)
   //
   // stem width and positioning
   //
-  stem_label = new QLabel(tr("Stron&g Stem Width&nbsp;<br>"
-                             "and Positioning:"));
+  stem_label = new QLabel(tr("Stem Width and Positionin&g Mode"));
   stem_label->setToolTip(
-    tr("<b>TTFautohint</b> provides two different hinting algorithms"
+    tr("<b>TTFautohint</b> provides three different hinting algorithms"
        " that can be selected for various hinting modes."
        ""
-       "<p><i>strong</i> (checkbox set):"
+       "<p><i>strong</i>:"
        " Position horizontal stems and snap stem widths"
        " to integer pixel values.  While making the output look crisper,"
        " outlines become more distorted.</p>"
        ""
-       "<p><i>smooth</i> (checkbox not set):"
+       "<p><i>quantized</i>:"
        " Use discrete values for horizontal stems and stem widths."
        "  This only slightly increases the contrast"
-       " but avoids larger outline distortion.</p>"));
+       " but avoids larger outline distortion.</p>"
+       ""
+       "<p><i>natural</i>:"
+       " Don't change horizontal stem widths"
+       " but use discrete values for stem positioning."
+       " This is what FreeType's"
+       " &lsquo;light&rsquo; hinting mode does.</p>"));
 
-  gray_box = new QCheckBox(tr("Grayscale"));
-  gray_box->setToolTip(
+  QStringList mode_list = QStringList() << "natural"
+                                        << "quantized"
+                                        << "strong";
+
+  gray_label = new QLabel(tr("Grayscale:"));
+  gray_box = new QComboBox;
+  gray_box->insertItems(0, mode_list);
+  gray_label->setToolTip(
     tr("<b></b>Grayscale rendering, no ClearType activated."));
+
+  // this must come after the creation of `gray_box'
+  // (you get a bus error otherwise)
   stem_label->setBuddy(gray_box);
 
-  gdi_box = new QCheckBox(tr("GDI ClearType"));
-  gdi_box->setToolTip(
+  gdi_label = new QLabel(tr("GDI ClearType:"));
+  gdi_box = new QComboBox;
+  gdi_box->insertItems(0, mode_list);
+  gdi_label->setToolTip(
     tr("GDI ClearType rendering,"
        " introduced in 2000 for Windows XP.<br>"
        "The rasterizer version (as returned by the"
@@ -1852,8 +1887,10 @@ Main_GUI::create_layout(bool horizontal_layout)
        " 36&nbsp;&le; version &lt;&nbsp;38, and ClearType is enabled.<br>"
        "Along the vertical axis, this mode behaves like B/W rendering."));
 
-  dw_box = new QCheckBox(tr("DW ClearType"));
-  dw_box->setToolTip(
+  dw_label = new QLabel(tr("DW ClearType:"));
+  dw_box = new QComboBox;
+  dw_box->insertItems(0, mode_list);
+  dw_label->setToolTip(
     tr("DirectWrite ClearType rendering,"
        " introduced in 2008 for Windows Vista.<br>"
        "The rasterizer version (as returned by the"
@@ -2000,10 +2037,15 @@ Main_GUI::create_vertical_layout()
   gui_layout->setRowMinimumHeight(row, 20); // XXX urgh, pixels...
   gui_layout->setRowStretch(row++, 1);
 
-  gui_layout->addWidget(stem_label, row, 0, Qt::AlignRight | Qt::AlignBottom);
-  gui_layout->addWidget(gray_box, row++, 1, Qt::AlignBottom);
-  gui_layout->addWidget(gdi_box, row++, 1);
-  gui_layout->addWidget(dw_box, row++, 1);
+  // this item spans two columns
+  gui_layout->addWidget(stem_label, row++, 0, 1, 2, Qt::AlignCenter);
+
+  gui_layout->addWidget(gray_label, row, 0, Qt::AlignRight);
+  gui_layout->addWidget(gray_box, row++, 1, Qt::AlignLeft);
+  gui_layout->addWidget(gdi_label, row, 0, Qt::AlignRight);
+  gui_layout->addWidget(gdi_box, row++, 1, Qt::AlignLeft);
+  gui_layout->addWidget(dw_label, row, 0, Qt::AlignRight);
+  gui_layout->addWidget(dw_box, row++, 1, Qt::AlignLeft);
 
   gui_layout->setRowMinimumHeight(row, 30); // XXX urgh, pixels...
   gui_layout->setRowStretch(row++, 1);
@@ -2118,11 +2160,6 @@ Main_GUI::create_horizontal_layout()
   gui_layout->addWidget(stem_width_box, row++, 2, Qt::AlignLeft);
   gui_layout->addWidget(default_stem_width_box, row++, 2);
 
-  gui_layout->setRowMinimumHeight(row, 30); // XXX urgh, pixels...
-  gui_layout->setRowStretch(row++, 1);
-
-  gui_layout->addLayout(run_layout, row, 0, row, -1);
-
   // column separator
   gui_layout->setColumnMinimumWidth(3, 20); // XXX urgh, pixels...
   gui_layout->setColumnStretch(3, 1);
@@ -2146,10 +2183,20 @@ Main_GUI::create_horizontal_layout()
   gui_layout->setRowMinimumHeight(row, 20); // XXX urgh, pixels...
   gui_layout->setRowStretch(row++, 1);
 
-  gui_layout->addWidget(stem_label, row, 3, Qt::AlignRight | Qt::AlignBottom);
-  gui_layout->addWidget(gray_box, row++, 4, Qt::AlignBottom);
-  gui_layout->addWidget(gdi_box, row++, 4);
-  gui_layout->addWidget(dw_box, row++, 4);
+  // this item spans two columns
+  gui_layout->addWidget(stem_label, row++, 3, 1, 2, Qt::AlignCenter);
+
+  gui_layout->addWidget(gray_label, row, 3, Qt::AlignRight);
+  gui_layout->addWidget(gray_box, row++, 4, Qt::AlignLeft);
+  gui_layout->addWidget(gdi_label, row, 3, Qt::AlignRight);
+  gui_layout->addWidget(gdi_box, row++, 4, Qt::AlignLeft);
+  gui_layout->addWidget(dw_label, row, 3, Qt::AlignRight);
+  gui_layout->addWidget(dw_box, row++, 4, Qt::AlignLeft);
+
+  gui_layout->setRowMinimumHeight(row, 30); // XXX urgh, pixels...
+  gui_layout->setRowStretch(row++, 1);
+
+  gui_layout->addLayout(run_layout, row, 0, row, -1);
 
   // margin
   gui_layout->setColumnMinimumWidth(5, 10); // XXX urgh, pixels...
@@ -2325,12 +2372,9 @@ Main_GUI::set_defaults()
   if (TTFA_info)
     TTFA_box->setChecked(true);
 
-  if (gray_strong_stem_width)
-    gray_box->setChecked(true);
-  if (gdi_cleartype_strong_stem_width)
-    gdi_box->setChecked(true);
-  if (dw_cleartype_strong_stem_width)
-    dw_box->setChecked(true);
+  gray_box->setCurrentIndex(gray_stem_width_mode + 1);
+  gdi_box->setCurrentIndex(gdi_cleartype_stem_width_mode + 1);
+  dw_box->setCurrentIndex(dw_cleartype_stem_width_mode + 1);
 
   run_button->setEnabled(false);
 
