@@ -34,7 +34,8 @@ TA_control_new(Control_Type type,
                number_range* point_set,
                double x_shift,
                double y_shift,
-               number_range* ppem_set)
+               number_range* ppem_set,
+               int line_number)
 {
   Control* control;
 
@@ -44,10 +45,9 @@ TA_control_new(Control_Type type,
     return NULL;
 
   control->type = type;
-
   control->font_idx = font_idx;
   control->glyph_idx = glyph_idx;
-  control->points = number_set_normalize(number_set_reverse(point_set));
+  control->points = number_set_reverse(point_set);
 
   switch (control->type)
   {
@@ -60,27 +60,35 @@ TA_control_new(Control_Type type,
                              + (y_shift > 0 ? 0.5 : -0.5));
     break;
 
-  case Control_Segment_Left:
-  case Control_Segment_Right:
+  case Control_Single_Point_Segment_Left:
+  case Control_Single_Point_Segment_Right:
     /* offsets */
     control->x_shift = (int)x_shift;
     control->y_shift = (int)y_shift;
     break;
 
-  case Control_Segment_None:
+  case Control_Single_Point_Segment_None:
     control->x_shift = 0;
     control->y_shift = 0;
     break;
 
-  case Control_Script_Feature:
+  case Control_Script_Feature_Glyphs:
     /* the `glyph_idx' field holds the style; */
     /* the `points' field holds the glyph index set */
     break;
+
+  case Control_Script_Feature_Widths:
+    /* the `glyph_idx' field holds the style */
+    /* (or a feature for all scripts); */
+    /* the `points' field holds the width set; */
+    break;
   }
 
-  control->ppems = number_set_normalize(number_set_reverse(ppem_set));
+  control->ppems = number_set_reverse(ppem_set);
   control->next = NULL;
 
+  control->line_number = line_number;
+
   return control;
 }
 
@@ -163,7 +171,8 @@ control_show_line(FONT* font,
 
   face = font->sfnts[control->font_idx].face;
   glyph_name_buf[0] = '\0';
-  if (control->type != Control_Script_Feature
+  if (!(control->type == Control_Script_Feature_Glyphs
+        || control->type == Control_Script_Feature_Widths)
       && FT_HAS_GLYPH_NAMES(face))
     FT_Get_Glyph_Name(face, (FT_UInt)control->glyph_idx, glyph_name_buf, 64);
 
@@ -199,29 +208,29 @@ control_show_line(FONT* font,
                        ppems_buf);
     break;
 
-  case Control_Segment_Left:
-  case Control_Segment_Right:
+  case Control_Single_Point_Segment_Left:
+  case Control_Single_Point_Segment_Right:
     /* display glyph index if we don't have a glyph name */
     if (*glyph_name_buf)
       s = sdscatprintf(s, "%ld %s %s %s",
                        control->font_idx,
                        glyph_name_buf,
-                       control->type == Control_Segment_Left ? "left"
-                                                             : "right",
+                       control->type == Control_Single_Point_Segment_Left
+                         ? "left" : "right",
                        points_buf);
     else
       s = sdscatprintf(s, "%ld %ld %s %s",
                        control->font_idx,
                        control->glyph_idx,
-                       control->type == Control_Segment_Left ? "left"
-                                                             : "right",
+                       control->type == Control_Single_Point_Segment_Left
+                         ? "left" : "right",
                        points_buf);
 
     if (control->x_shift || control->y_shift)
       s = sdscatprintf(s, " (%d,%d)", control->x_shift, control->y_shift);
     break;
 
-  case Control_Segment_None:
+  case Control_Single_Point_Segment_None:
     /* display glyph index if we don't have a glyph name */
     if (*glyph_name_buf)
       s = sdscatprintf(s, "%ld %s nodir %s",
@@ -235,7 +244,7 @@ control_show_line(FONT* font,
                        points_buf);
     break;
 
-  case Control_Script_Feature:
+  case Control_Script_Feature_Glyphs:
     {
       TA_StyleClass style_class = ta_style_classes[control->glyph_idx];
       char feature_name[5];
@@ -251,6 +260,35 @@ control_show_line(FONT* font,
                        points_buf);
     }
     break;
+
+  case Control_Script_Feature_Widths:
+    {
+      char feature_name[5];
+      const char* script_name;
+
+
+      feature_name[4] = '\0';
+
+      if (control->glyph_idx > 0)
+      {
+        TA_StyleClass  style_class = ta_style_classes[control->glyph_idx];
+
+
+        script_name = script_names[style_class->script];
+        hb_tag_to_string(feature_tags[style_class->coverage], feature_name);
+      }
+      else
+      {
+        script_name = "*";
+        hb_tag_to_string(feature_tags[-control->glyph_idx], feature_name);
+      }
+
+      s = sdscatprintf(s, "%ld %s %s width %s",
+                       control->font_idx,
+                       script_name,
+                       feature_name,
+                       points_buf);
+    }
   }
 
 Exit:
@@ -455,7 +493,7 @@ TA_control_apply_coverage(SFNT* sfnt,
     int style;
 
 
-    if (control->type != Control_Script_Feature)
+    if (control->type != Control_Script_Feature_Glyphs)
       goto Skip;
     if (control->font_idx != sfnt->face->face_index)
       goto Skip;
@@ -466,7 +504,7 @@ TA_control_apply_coverage(SFNT* sfnt,
     glyph_idx_iter.range = control->points;
     glyph_idx = number_set_get_first(&glyph_idx_iter);
 
-    while (glyph_idx_iter.range)
+    while (glyph_idx >= 0)
     {
       /* assign new style but retain digit property */
       gstyles[glyph_idx] &= TA_DIGIT;
@@ -481,6 +519,54 @@ TA_control_apply_coverage(SFNT* sfnt,
 }
 
 
+/* handle stem width data from the control instructions file; */
+
+void
+TA_control_set_stem_widths(TA_LatinMetrics metrics,
+                           FONT* font)
+{
+  Control* control = font->control;
+  FT_Face face = font->loader->face;
+  TA_WidthRec* widths = metrics->axis[TA_DIMENSION_VERT].widths;
+
+
+  while (control)
+  {
+    TA_StyleClass style_class = metrics->root.style_class;
+
+    number_set_iter width_iter;
+    int width;
+    int i;
+
+
+    if (control->type != Control_Script_Feature_Widths)
+      goto Skip;
+    if (control->font_idx != face->face_index)
+      goto Skip;
+    /* `control->glyph_idx' holds either a style */
+    /* or a feature for all scripts */
+    if (!(control->glyph_idx == style_class->style
+          || -control->glyph_idx == style_class->coverage))
+      goto Skip;
+
+    /* `control->points' holds the width set */
+    width_iter.range = control->points;
+    width = number_set_get_first(&width_iter);
+
+    i = 0;
+    while (width >= 0)
+    {
+      widths[i++].org = width;
+      width = number_set_get_next(&width_iter);
+    }
+    metrics->axis[TA_DIMENSION_VERT].width_count = i;
+
+  Skip:
+    control = control->next;
+  }
+}
+
+
 /* node structure for control instruction data */
 
 typedef struct Node Node;
@@ -592,13 +678,14 @@ TA_control_build_tree(FONT* font)
     long glyph_idx = control->glyph_idx;
     int x_shift = control->x_shift;
     int y_shift = control->y_shift;
+    int line_number = control->line_number;
 
     number_set_iter ppems_iter;
     int ppem;
 
 
     /* we don't store style information in the tree */
-    if (type == Control_Script_Feature)
+    if (type == Control_Script_Feature_Glyphs)
     {
       control = control->next;
       continue;
@@ -608,12 +695,12 @@ TA_control_build_tree(FONT* font)
     ppem = number_set_get_first(&ppems_iter);
 
     /* ppem is always zero for one-point segments */
-    if (type == Control_Segment_Left
-        || type == Control_Segment_Right
-        || type == Control_Segment_None)
+    if (type == Control_Single_Point_Segment_Left
+        || type == Control_Single_Point_Segment_Right
+        || type == Control_Single_Point_Segment_None)
       goto Points_Loop;
 
-    while (ppems_iter.range)
+    while (ppem >= 0)
     {
       number_set_iter points_iter;
       int point_idx;
@@ -623,7 +710,7 @@ TA_control_build_tree(FONT* font)
       points_iter.range = control->points;
       point_idx = number_set_get_first(&points_iter);
 
-      while (points_iter.range)
+      while (point_idx >= 0)
       {
         Node* node;
         Node* val;
@@ -640,13 +727,12 @@ TA_control_build_tree(FONT* font)
         node->ctrl.point_idx = point_idx;
         node->ctrl.x_shift = x_shift;
         node->ctrl.y_shift = y_shift;
+        node->ctrl.line_number = line_number;
 
         val = LLRB_INSERT(control_data, control_data_head, node);
-        if (val)
-          free(node);
         if (val && font->debug)
         {
-          /* entry is already present; we ignore it */
+          /* entry is already present; we overwrite it */
           Control d;
           number_range ppems;
           number_range points;
@@ -674,12 +760,27 @@ TA_control_build_tree(FONT* font)
           s = control_show_line(font, &d);
           if (s)
           {
-            fprintf(stderr, "Control instruction `%s' ignored.\n", s);
+            fprintf(stderr, "Control instruction `%s' (line %d)"
+                            " overwrites data from line %d.\n",
+                            s, line_number, val->ctrl.line_number);
             sdsfree(s);
           }
 
           emit_newline = 1;
         }
+        if (val)
+        {
+          val->ctrl.type = type;
+          val->ctrl.font_idx = font_idx;
+          val->ctrl.glyph_idx = glyph_idx;
+          val->ctrl.ppem = ppem;
+          val->ctrl.point_idx = point_idx;
+          val->ctrl.x_shift = x_shift;
+          val->ctrl.y_shift = y_shift;
+          val->ctrl.line_number = line_number;
+
+          free(node);
+        }
 
         point_idx = number_set_get_next(&points_iter);
       }
@@ -764,9 +865,9 @@ TA_control_segment_dir_collect(FONT* font,
       break;
 
     /* check type */
-    if (!(ctrl->type == Control_Segment_Left
-          || ctrl->type == Control_Segment_Right
-          || ctrl->type == Control_Segment_None))
+    if (!(ctrl->type == Control_Single_Point_Segment_Left
+          || ctrl->type == Control_Single_Point_Segment_Right
+          || ctrl->type == Control_Single_Point_Segment_None))
       break;
 
     /* too large values of font and glyph indices in `ctrl' */
@@ -783,7 +884,8 @@ TA_control_segment_dir_collect(FONT* font,
                           NULL,
                           ctrl->x_shift,
                           ctrl->y_shift,
-                          NULL);
+                          NULL,
+                          ctrl->line_number);
     if (!elem)
     {
       TA_control_free(control_segment_dirs_head);
@@ -825,9 +927,9 @@ TA_control_segment_dir_get_next(FONT* font,
 
   /* the `glyph_idx' field gets abused for `point_idx' */
   *point_idx = (int)control_segment_dirs_cur->glyph_idx;
-  *dir = control_segment_dirs_cur->type == Control_Segment_Left
+  *dir = control_segment_dirs_cur->type == Control_Single_Point_Segment_Left
            ? TA_DIR_LEFT
-           : control_segment_dirs_cur->type == Control_Segment_Right
+           : control_segment_dirs_cur->type == Control_Single_Point_Segment_Right
              ? TA_DIR_RIGHT
              : TA_DIR_NONE;
   *left_offset = control_segment_dirs_cur->x_shift;
