@@ -1,7 +1,7 @@
 /* taerror.c */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -33,7 +33,7 @@ static TA_error TA_Errors[] =
 #define FT_ERROR_END_LIST /* empty */
 #include FT_ERRORS_H
 
-#undef __TTFAUTOHINT_ERRORS_H__
+#undef TTFAUTOHINT_ERRORS_H_
 #define TA_ERRORDEF(e, v, s) { e, s },
 #define TA_ERROR_START_LIST /* empty */
 #define TA_ERROR_END_LIST { 0, NULL } };
