@@ -1,7 +1,7 @@
 /* taglobal.c */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -24,13 +24,14 @@
 
 
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) \
+#define SCRIPT(s, S, d, h, H, ss) \
           const TA_ScriptClassRec ta_ ## s ## _script_class = \
           { \
             TA_SCRIPT_ ## S, \
             ta_ ## s ## _uniranges, \
             ta_ ## s ## _nonbase_uniranges, \
-            sc1, sc2, sc3 \
+            TA_ ## H, \
+            ss \
           };
 
 #include <ttfautohint-scripts.h>
@@ -70,7 +71,7 @@ TA_WritingSystemClass const ta_writing_system_classes[] =
 
 
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) \
+#define SCRIPT(s, S, d, h, H, ss) \
           &ta_ ## s ## _script_class,
 
 TA_ScriptClass const ta_script_classes[] =
@@ -232,11 +233,12 @@ ta_face_globals_compute_style_coverage(TA_FaceGlobals globals)
   for (ss = 0; ta_style_classes[ss]; ss++)
   {
     TA_StyleClass style_class = ta_style_classes[ss];
+    FT_UInt* sample_glyph = &globals->sample_glyphs[ss];
     TA_ScriptClass script_class = ta_script_classes[style_class->script];
     TA_Script_UniRange range;
 
 
-    if (script_class->script_uni_ranges->first == 0)
+    if (!script_class->script_uni_ranges->first)
       continue;
 
     /* scan all Unicode points in the range and */
@@ -259,7 +261,11 @@ ta_face_globals_compute_style_coverage(TA_FaceGlobals globals)
         if (gindex != 0
             && gindex < (FT_ULong)globals->glyph_count
             && (gstyles[gindex] & TA_STYLE_MASK) == TA_STYLE_UNASSIGNED)
+        {
           gstyles[gindex] = (FT_UShort)ss;
+          if (!*sample_glyph)
+            *sample_glyph = gindex;
+        }
 
         for (;;)
         {
@@ -270,7 +276,11 @@ ta_face_globals_compute_style_coverage(TA_FaceGlobals globals)
 
           if (gindex < (FT_ULong)globals->glyph_count
               && (gstyles[gindex] & TA_STYLE_MASK) == TA_STYLE_UNASSIGNED)
+          {
             gstyles[gindex] = (FT_UShort)ss;
+            if (!*sample_glyph)
+              *sample_glyph = gindex;
+          }
         }
       }
 
@@ -288,7 +298,11 @@ ta_face_globals_compute_style_coverage(TA_FaceGlobals globals)
         if (gindex != 0
             && gindex < (FT_ULong)globals->glyph_count
             && (gstyles[gindex] & TA_STYLE_MASK) == (FT_UShort)ss)
+        {
           gstyles[gindex] |= TA_NONBASE;
+          if (!*sample_glyph)
+            *sample_glyph = gindex;
+        }
 
         for (;;)
         {
@@ -299,30 +313,47 @@ ta_face_globals_compute_style_coverage(TA_FaceGlobals globals)
 
           if (gindex < (FT_ULong)globals->glyph_count
               && (gstyles[gindex] & TA_STYLE_MASK) == (FT_UShort)ss)
+          {
             gstyles[gindex] |= TA_NONBASE;
+            if (!*sample_glyph)
+              *sample_glyph = gindex;
+          }
         }
       }
     }
     else
     {
       /* get glyphs not directly addressable by cmap */
-      ta_get_coverage(globals, style_class, gstyles);
+      ta_shaper_get_coverage(globals,
+                             style_class,
+                             gstyles,
+                             sample_glyph,
+                             0);
     }
   }
 
-  /* handle the default OpenType features of the default script ... */
-  ta_get_coverage(globals, ta_style_classes[dflt], gstyles);
-
-  /* ... and the remaining default OpenType features */
+  /* handle the remaining default OpenType features ... */
   for (ss = 0; ta_style_classes[ss]; ss++)
   {
-    TA_StyleClass  style_class = ta_style_classes[ss];
+    TA_StyleClass style_class = ta_style_classes[ss];
+    FT_UInt* sample_glyph = &globals->sample_glyphs[ss];
 
 
-    if (ss != dflt && style_class->coverage == TA_COVERAGE_DEFAULT)
-      ta_get_coverage(globals, style_class, gstyles);
+    if (style_class->coverage == TA_COVERAGE_DEFAULT)
+      ta_shaper_get_coverage(globals,
+                             style_class,
+                             gstyles,
+                             sample_glyph,
+                             0);
   }
 
+  /* ... and finally the default OpenType features of the default script */
+  ta_shaper_get_coverage(globals,
+                         ta_style_classes[dflt],
+                         gstyles,
+                         &globals->sample_glyphs[dflt],
+                         1);
+
   /* mark ASCII digits */
   for (i = 0x30; i <= 0x39; i++)
   {
@@ -341,6 +372,9 @@ ta_face_globals_compute_style_coverage(TA_FaceGlobals globals)
     FT_Long nn;
 
 
+    /* no need for updating `sample_glyphs'; */
+    /* the composite itself is certainly a valid sample glyph */
+
     for (nn = 0; nn < globals->glyph_count; nn++)
     {
       if ((gstyles[nn] & TA_STYLE_MASK) == TA_STYLE_UNASSIGNED)
@@ -452,6 +486,7 @@ ta_face_globals_new(FT_Face face,
   globals->glyph_styles = (FT_UShort*)(globals + 1);
   globals->font = font;
   globals->hb_font = hb_ft_font_create(face, NULL);
+  globals->hb_buf = hb_buffer_create();
 
   error = ta_face_globals_compute_style_coverage(globals);
   if (error)
@@ -490,17 +525,14 @@ ta_face_globals_free(TA_FaceGlobals globals)
           writing_system_class->style_metrics_done(globals->metrics[nn]);
 
         free(globals->metrics[nn]);
-        globals->metrics[nn] = NULL;
       }
     }
 
     hb_font_destroy(globals->hb_font);
+    hb_buffer_destroy(globals->hb_buf);
 
-    globals->hb_font = NULL;
-    globals->glyph_count = 0;
-    globals->glyph_styles = NULL; /* no need to free this one! */
-    globals->face = NULL;
-
+    /* no need to free `globals->glyph_styles'; */
+    /* it is part of the `globals' array */
     free(globals);
   }
 }
@@ -537,7 +569,7 @@ ta_face_globals_get_metrics(TA_FaceGlobals globals,
     ta_writing_system_classes[style_class->writing_system];
 
   metrics = globals->metrics[style];
-  if (metrics == NULL)
+  if (!metrics)
   {
     /* create the global metrics object if necessary */
     metrics = (TA_StyleMetrics)
@@ -553,8 +585,10 @@ ta_face_globals_get_metrics(TA_FaceGlobals globals,
 
     if (writing_system_class->style_metrics_init)
     {
-      error = writing_system_class->style_metrics_init(metrics,
-                                                       globals->face);
+      error = writing_system_class->style_metrics_init(
+                                      metrics,
+                                      globals->face,
+                                      globals->font->reference);
       if (error)
       {
         if (writing_system_class->style_metrics_done)
