@@ -1,7 +1,7 @@
 /* taglobal.h */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -17,19 +17,19 @@
 
 /* heavily modified 2011 by Werner Lemberg <wl@gnu.org> */
 
-#ifndef __TAGLOBAL_H__
-#define __TAGLOBAL_H__
+#ifndef TAGLOBAL_H_
+#define TAGLOBAL_H_
 
 #include "ta.h"
 #include "tatypes.h"
-#include "taharfbuzz.h"
+#include "tashaper.h"
 
 
 extern TA_WritingSystemClass const ta_writing_system_classes[];
 
 
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) \
+#define SCRIPT(s, S, d, h, H, ss) \
           extern const TA_ScriptClassRec ta_ ## s ## _script_class;
 
 #include "ttfautohint-scripts.h"
@@ -58,7 +58,7 @@ extern const char* ta_style_names[];
 /* index of fallback style in `ta_style_classes' */
 #define TA_STYLE_FALLBACK TA_STYLE_NONE_DFLT
 /* default script for OpenType */
-#define TA_SCRIPT_DEFAULT  AF_SCRIPT_LATN
+#define TA_SCRIPT_DEFAULT TA_SCRIPT_LATN
 
 /* a bit mask for TA_DIGIT and TA_NONBASE */
 #define TA_STYLE_MASK 0x3FFF
@@ -84,11 +84,13 @@ typedef struct TA_FaceGlobalsRec_
   FT_UShort* glyph_styles;
 
   hb_font_t* hb_font;
+  hb_buffer_t* hb_buf; /* for feature comparison */
 
   /* per-face auto-hinter properties */
   FT_UInt increase_x_height;
 
   TA_StyleMetrics metrics[TA_STYLE_MAX];
+  FT_UInt sample_glyphs[TA_STYLE_MAX]; /* per-style sample glyph indices */
 
   FONT* font; /* to access global properties */
 } TA_FaceGlobalsRec;
@@ -115,6 +117,6 @@ FT_Bool
 ta_face_globals_is_digit(TA_FaceGlobals globals,
                          FT_UInt gindex);
 
-#endif /* __TAGLOBAL_H__ */
+#endif /* TAGLOBAL_H_ */
 
 /* end of taglobal.h */
