@@ -1,7 +1,7 @@
 /* taglyf.c */
 
 /*
- * Copyright (C) 2011-2016 by Werner Lemberg.
+ * Copyright (C) 2011-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -1321,20 +1321,8 @@ TA_sfnt_adjust_coverage(SFNT* sfnt,
     FT_UShort* gstyles = master_globals->glyph_styles;
 #ifdef TA_DEBUG
     FT_UInt count;
-#endif
 
 
-    for (nn = 0; nn < master_globals->glyph_count; nn++)
-    {
-      if ((gstyles[nn] & TA_STYLE_MASK) == TA_STYLE_UNASSIGNED)
-      {
-        gstyles[nn] &= ~TA_STYLE_MASK;
-        gstyles[nn] |= master_globals->font->fallback_style;
-      }
-    }
-
-#ifdef TA_DEBUG
-
     if (sfnt->face->num_faces > 1)
       TA_LOG_GLOBAL(("\n"
                      "using fallback style `%s' for unassigned glyphs"
@@ -1350,8 +1338,7 @@ TA_sfnt_adjust_coverage(SFNT* sfnt,
 
     for (nn = 0; nn < master_globals->glyph_count; nn++)
     {
-      if ((gstyles[nn] & TA_STYLE_MASK)
-          == master_globals->font->fallback_style)
+      if ((gstyles[nn] & TA_STYLE_MASK) == TA_STYLE_UNASSIGNED)
       {
         if (!(count % 10))
           TA_LOG_GLOBAL((" "));
@@ -1371,6 +1358,15 @@ TA_sfnt_adjust_coverage(SFNT* sfnt,
 
 #endif /* TA_DEBUG */
 
+    for (nn = 0; nn < master_globals->glyph_count; nn++)
+    {
+      if ((gstyles[nn] & TA_STYLE_MASK) == TA_STYLE_UNASSIGNED)
+      {
+        gstyles[nn] &= ~TA_STYLE_MASK;
+        gstyles[nn] |= master_globals->font->fallback_style;
+      }
+    }
+
     data->adjusted = 1;
   }
 }
