@@ -1,7 +1,7 @@
 /* talatin.h */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -17,8 +17,8 @@
 
 /* heavily modified 2011 by Werner Lemberg <wl@gnu.org> */
 
-#ifndef __TALATIN_H__
-#define __TALATIN_H__
+#ifndef TALATIN_H_
+#define TALATIN_H_
 
 #include "tatypes.h"
 #include "tahints.h"
@@ -38,6 +38,8 @@ extern const TA_WritingSystemClassRec ta_latin_writing_system_class;
 
 #define TA_LATIN_IS_TOP_BLUE(b) \
           ((b)->properties & TA_BLUE_PROPERTY_LATIN_TOP)
+#define TA_LATIN_IS_SUB_TOP_BLUE(b) \
+          ((b)->properties & TA_BLUE_PROPERTY_LATIN_SUB_TOP)
 #define TA_LATIN_IS_NEUTRAL_BLUE(b) \
           ((b)->properties & TA_BLUE_PROPERTY_LATIN_NEUTRAL)
 #define TA_LATIN_IS_X_HEIGHT_BLUE(b) \
@@ -50,8 +52,10 @@ extern const TA_WritingSystemClassRec ta_latin_writing_system_class;
 
 #define TA_LATIN_BLUE_ACTIVE (1U << 0) /* set if zone height is <= 3/4px */
 #define TA_LATIN_BLUE_TOP (1U << 1) /* set if we have a top blue zone */
-#define TA_LATIN_BLUE_NEUTRAL (1U << 2) /* set if we have neutral blue zone */
-#define TA_LATIN_BLUE_ADJUSTMENT (1U << 3) /* used for scale adjustment */
+#define TA_LATIN_BLUE_SUB_TOP (1U << 2) /* set if we have a */
+                                        /* subscript top blue zone */
+#define TA_LATIN_BLUE_NEUTRAL (1U << 3) /* set if we have neutral blue zone */
+#define TA_LATIN_BLUE_ADJUSTMENT (1U << 4) /* used for scale adjustment */
                                            /* optimization */
 
 
@@ -59,6 +63,8 @@ typedef struct TA_LatinBlueRec_
 {
   TA_WidthRec ref;
   TA_WidthRec shoot;
+  FT_Pos ascender;
+  FT_Pos descender;
   FT_UInt flags;
 } TA_LatinBlueRec, *TA_LatinBlue;
 
@@ -75,8 +81,8 @@ typedef struct TA_LatinAxisRec_
   FT_Bool extra_light; /* is standard width very light? */
 
   /* ignored for horizontal metrics */
-  FT_UInt blue_count;
-  /* we add two blue zones for usWinAscent and usWinDescent */
+  FT_UInt blue_count; /* does not contain artificial blue zones */
+  /* we add two artificial blue zones for usWinAscent and usWinDescent */
   TA_LatinBlueRec blues[TA_BLUE_STRINGSET_MAX + 2];
 
   FT_Fixed org_scale;
@@ -94,7 +100,8 @@ typedef struct TA_LatinMetricsRec_
 
 FT_Error
 ta_latin_metrics_init(TA_LatinMetrics metrics,
-                      FT_Face face);
+                      FT_Face face,
+                      FT_Face reference);
 
 void
 ta_latin_metrics_scale(TA_LatinMetrics metrics,
@@ -147,6 +154,6 @@ ta_latin_hints_detect_features(TA_GlyphHints hints,
                                TA_WidthRec* widths,
                                TA_Dimension dim);
 
-#endif /* __TALATIN_H__ */
+#endif /* TALATIN_H_ */
 
 /* end of talatin.h */
