@@ -1,7 +1,7 @@
 /* taranges.c */
 
 /*
- * Copyright (C) 2014-2016 by Werner Lemberg.
+ * Copyright (C) 2014-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -78,6 +78,19 @@
 /* of the corresponding `ta_xxxx_uniranges' ranges */
 
 
+const TA_Script_UniRangeRec ta_adlm_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1E900, 0x1E95F), /* Adlam */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_adlm_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1D944, 0x1E94A),
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+
 const TA_Script_UniRangeRec ta_arab_uniranges[] =
 {
   TA_UNIRANGE_REC( 0x0600,  0x06FF), /* Arabic */
@@ -127,6 +140,37 @@ const TA_Script_UniRangeRec ta_armn_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_avst_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10B00, 0x10B3F), /* Avestan */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_avst_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10B39, 0x10B3F),
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+
+const TA_Script_UniRangeRec ta_bamu_uniranges[] =
+{
+  TA_UNIRANGE_REC( 0xA6A0,  0xA6FF), /* Bamum */
+#if 0
+  /* The characters in the Bamum supplement are pictograms, */
+  /* not (directly) related to the syllabic Bamum script */
+  TA_UNIRANGE_REC(0x16800, 0x16A3F), /* Bamum Supplement */
+#endif
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_bamu_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xA6F0,  0xA6F1),
+  TA_UNIRANGE_REC(     0,       0)
+};
+
+
 const TA_Script_UniRangeRec ta_beng_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0980, 0x09FF), /* Bengali */
@@ -144,6 +188,58 @@ const TA_Script_UniRangeRec ta_beng_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_buhd_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1740,  0x175F), /* Buhid */
+  TA_UNIRANGE_REC(     0,       0)
+};
+
+const TA_Script_UniRangeRec ta_buhd_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1752,  0x1753),
+  TA_UNIRANGE_REC(     0,       0)
+};
+
+
+const TA_Script_UniRangeRec ta_cakm_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x11100, 0x1114F), /* Chakma */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_cakm_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x11100, 0x11102),
+  TA_UNIRANGE_REC(0x11127, 0x11134),
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+
+const TA_Script_UniRangeRec ta_cans_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1400,  0x167F), /* Unified Canadian Aboriginal Syllabics */
+  TA_UNIRANGE_REC(0x18B0,  0x18FF), /* Unified Canadian Aboriginal Syllabics Extended */
+  TA_UNIRANGE_REC(     0,       0)
+};
+
+const TA_Script_UniRangeRec ta_cans_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
+const TA_Script_UniRangeRec ta_cari_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x102A0, 0x102DF), /* Carian */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_cari_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
 const TA_Script_UniRangeRec ta_cher_uniranges[] =
 {
   TA_UNIRANGE_REC(0x13A0, 0x13FF), /* Cherokee */
@@ -157,6 +253,31 @@ const TA_Script_UniRangeRec ta_cher_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_copt_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x2C80, 0x2CFF), /* Coptic */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_copt_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x2CEF, 0x2CF1),
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+
+const TA_Script_UniRangeRec ta_cprt_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10800, 0x1083F), /* Cypriot */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_cprt_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
 const TA_Script_UniRangeRec ta_cyrl_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0400, 0x04FF), /* Cyrillic */
@@ -207,6 +328,18 @@ const TA_Script_UniRangeRec ta_deva_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_dsrt_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10400, 0x1044F), /* Deseret */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_dsrt_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
 const TA_Script_UniRangeRec ta_ethi_uniranges[] =
 {
   TA_UNIRANGE_REC(0x1200, 0x137F), /* Ethiopic */
@@ -253,6 +386,32 @@ const TA_Script_UniRangeRec ta_geok_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_glag_uniranges[] =
+{
+  TA_UNIRANGE_REC( 0x2C00,  0x2C5F), /* Glagolitic */
+  TA_UNIRANGE_REC(0x1E000, 0x1E02F), /* Glagolitic Supplement */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_glag_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1E000, 0x1E02F),
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+
+const TA_Script_UniRangeRec ta_goth_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10330, 0x1034F), /* Gothic */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_goth_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
 const TA_Script_UniRangeRec ta_grek_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0370, 0x03FF), /* Greek and Coptic */
@@ -325,6 +484,19 @@ const TA_Script_UniRangeRec ta_hebr_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_kali_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xA900, 0xA92F), /* Kayah Li */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_kali_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xA926, 0xA92D),
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+
 const TA_Script_UniRangeRec ta_knda_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0C80, 0x0CFF), /* Kannada */
@@ -483,6 +655,18 @@ const TA_Script_UniRangeRec ta_latp_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_lisu_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xA4D0, 0xA4FF), /* Lisu */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_lisu_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
 const TA_Script_UniRangeRec ta_mlym_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0D00, 0x0D7F), /* Malayalam */
@@ -524,6 +708,93 @@ const TA_Script_UniRangeRec ta_mymr_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_nkoo_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x07C0, 0x07FF), /* N'Ko */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_nkoo_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x07EB, 0x07F5),
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+
+const TA_Script_UniRangeRec ta_olck_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1C50, 0x1C7F), /* Ol Chiki */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_olck_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
+const TA_Script_UniRangeRec ta_orkh_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10C00, 0x10C4F), /* Old Turkic */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_orkh_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
+const TA_Script_UniRangeRec ta_osge_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x104B0, 0x104FF), /* Osage */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_osge_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
+const TA_Script_UniRangeRec ta_osma_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10480, 0x104AF), /* Osmanya */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_osma_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
+const TA_Script_UniRangeRec ta_saur_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xA880, 0xA8DF), /* Saurashtra */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_saur_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xA880, 0xA881),
+  TA_UNIRANGE_REC(0xA8B4, 0xA8C5),
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+
+const TA_Script_UniRangeRec ta_shaw_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x10450, 0x1047F), /* Shavian */
+  TA_UNIRANGE_REC(      0,       0)
+};
+
+const TA_Script_UniRangeRec ta_shaw_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
 const TA_Script_UniRangeRec ta_sinh_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0D80, 0x0DFF), /* Sinhala */
@@ -538,6 +809,21 @@ const TA_Script_UniRangeRec ta_sinh_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_sund_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1B80, 0x1BBF), /* Sundanese */
+  TA_UNIRANGE_REC(0x1CC0, 0x1CCF), /* Sundanese Supplement */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_sund_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x1B80, 0x1B82),
+  TA_UNIRANGE_REC(0x1BA1, 0x1BAD),
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+
 const TA_Script_UniRangeRec ta_taml_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0B80, 0x0BFF), /* Tamil */
@@ -553,6 +839,23 @@ const TA_Script_UniRangeRec ta_taml_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_tavt_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xAA80, 0xAADF), /* Tai Viet */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_tavt_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xAAB0, 0xAAB0),
+  TA_UNIRANGE_REC(0xAAB2, 0xAAB4),
+  TA_UNIRANGE_REC(0xAAB7, 0xAAB8),
+  TA_UNIRANGE_REC(0xAABE, 0xAABF),
+  TA_UNIRANGE_REC(0xAAC1, 0xAAC1),
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+
 const TA_Script_UniRangeRec ta_telu_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0C00, 0x0C7F), /* Telugu */
@@ -584,6 +887,30 @@ const TA_Script_UniRangeRec ta_thai_nonbase_uniranges[] =
 };
 
 
+const TA_Script_UniRangeRec ta_tfng_uniranges[] =
+{
+  TA_UNIRANGE_REC(0x2D30, 0x2D7F), /* Tifinagh */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_tfng_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
+const TA_Script_UniRangeRec ta_vaii_uniranges[] =
+{
+  TA_UNIRANGE_REC(0xA500, 0xA63F), /* Vai */
+  TA_UNIRANGE_REC(     0,      0)
+};
+
+const TA_Script_UniRangeRec ta_vaii_nonbase_uniranges[] =
+{
+  TA_UNIRANGE_REC(0, 0)
+};
+
+
 const TA_Script_UniRangeRec ta_none_uniranges[] =
 {
   TA_UNIRANGE_REC(0, 0)
