@@ -1,7 +1,7 @@
 /* taranges.h */
 
 /*
- * Copyright (C) 2014-2015 by Werner Lemberg.
+ * Copyright (C) 2014-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -17,25 +17,25 @@
 
 /* heavily modified 2014 by Werner Lemberg <wl@gnu.org> */
 
-#ifndef __TARANGES_H__
-#define __TARANGES_H__
+#ifndef TARANGES_H_
+#define TARANGES_H_
 
 
 #include "tatypes.h"
 
 
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) \
+#define SCRIPT(s, S, d, h, H, ss) \
           extern const TA_Script_UniRangeRec ta_ ## s ## _uniranges[];
 
 #include "ttfautohint-scripts.h"
 
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) \
+#define SCRIPT(s, S, d, h, H, ss) \
           extern const TA_Script_UniRangeRec ta_ ## s ## _nonbase_uniranges[];
 
 #include "ttfautohint-scripts.h"
 
-#endif /* __TARANGES_H__ */
+#endif /* TARANGES_H_ */
 
 /* end of taranges.h */
