@@ -1,7 +1,7 @@
 /* tascript.c */
 
 /*
- * Copyright (C) 2014-2015 by Werner Lemberg.
+ * Copyright (C) 2014-2017 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -16,7 +16,7 @@
 
 
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) #s,
+#define SCRIPT(s, S, d, h, H, ss) #s,
 
 const char* script_names[] =
 {
