@@ -40,7 +40,7 @@ TA_sfnt_set_properties(SFNT* sfnt,
 }
 
 
-TA_Error
+TA_LIB_EXPORT TA_Error
 TTF_autohint(const char* options,
              ...)
 {
@@ -86,9 +86,9 @@ TTF_autohint(const char* options,
 
   FT_Long fallback_stem_width = 0;
 
-  FT_Bool gray_strong_stem_width = 0;
-  FT_Bool gdi_cleartype_strong_stem_width = 1;
-  FT_Bool dw_cleartype_strong_stem_width = 0;
+  FT_Int gray_stem_width_mode = TA_STEM_WIDTH_MODE_QUANTIZED;
+  FT_Int gdi_cleartype_stem_width_mode = TA_STEM_WIDTH_MODE_STRONG;
+  FT_Int dw_cleartype_stem_width_mode = TA_STEM_WIDTH_MODE_QUANTIZED;
 
   TA_Progress_Func progress = NULL;
   void* progress_data = NULL;
@@ -98,6 +98,9 @@ TTF_autohint(const char* options,
   TA_Info_Post_Func info_post = NULL;
   void* info_data = NULL;
 
+  TA_Alloc_Func allocate = NULL;
+  TA_Free_Func deallocate = NULL;
+
   FT_Bool windows_compatibility = 0;
   FT_Bool ignore_restrictions = 0;
   FT_Bool adjust_subglyphs = 0;
@@ -129,7 +132,7 @@ TTF_autohint(const char* options,
 
   op = options;
 
-  for(;;)
+  for (;;)
   {
     const char* start;
     size_t len;
@@ -156,6 +159,8 @@ TTF_autohint(const char* options,
     /* handle options -- don't forget to update parameter dump below! */
     if (COMPARE("adjust-subglyphs"))
       adjust_subglyphs = (FT_Bool)va_arg(ap, FT_Int);
+    else if (COMPARE("alloc-func"))
+      allocate = va_arg(ap, TA_Alloc_Func);
     else if (COMPARE("control-buffer"))
     {
       control_file = NULL;
@@ -178,8 +183,16 @@ TTF_autohint(const char* options,
       default_script_string = va_arg(ap, const char*);
     else if (COMPARE("dehint"))
       dehint = (FT_Bool)va_arg(ap, FT_Int);
+    else if (COMPARE("dw-cleartype-stem-width-mode"))
+      dw_cleartype_stem_width_mode = va_arg(ap, FT_Int);
     else if (COMPARE("dw-cleartype-strong-stem-width"))
-      dw_cleartype_strong_stem_width = (FT_Bool)va_arg(ap, FT_Int);
+    {
+      FT_Bool arg = (FT_Bool)va_arg(ap, FT_Int);
+
+
+      dw_cleartype_stem_width_mode = arg ? TA_STEM_WIDTH_MODE_STRONG
+                                         : TA_STEM_WIDTH_MODE_QUANTIZED;
+    }
     else if (COMPARE("epoch"))
       epoch = (unsigned long long)va_arg(ap, unsigned long long);
     else if (COMPARE("error-callback"))
@@ -194,10 +207,28 @@ TTF_autohint(const char* options,
       fallback_script_string = va_arg(ap, const char*);
     else if (COMPARE("fallback-stem-width"))
       fallback_stem_width = (FT_Long)va_arg(ap, FT_UInt);
+    else if (COMPARE("free-func"))
+      deallocate = va_arg(ap, TA_Free_Func);
+    else if (COMPARE("gdi-cleartype-stem-width-mode"))
+      gdi_cleartype_stem_width_mode = va_arg(ap, FT_Int);
     else if (COMPARE("gdi-cleartype-strong-stem-width"))
-      gdi_cleartype_strong_stem_width = (FT_Bool)va_arg(ap, FT_Int);
+    {
+      FT_Bool arg = (FT_Bool)va_arg(ap, FT_Int);
+
+
+      gdi_cleartype_stem_width_mode = arg ? TA_STEM_WIDTH_MODE_STRONG
+                                          : TA_STEM_WIDTH_MODE_QUANTIZED;
+    }
+    else if (COMPARE("gray-stem-width-mode"))
+      gray_stem_width_mode = va_arg(ap, FT_Int);
     else if (COMPARE("gray-strong-stem-width"))
-      gray_strong_stem_width = (FT_Bool)va_arg(ap, FT_Int);
+    {
+      FT_Bool arg = (FT_Bool)va_arg(ap, FT_Int);
+
+
+      gray_stem_width_mode = arg ? TA_STEM_WIDTH_MODE_STRONG
+                                 : TA_STEM_WIDTH_MODE_QUANTIZED;
+    }
     else if (COMPARE("hinting-limit"))
       hinting_limit = (FT_Long)va_arg(ap, FT_UInt);
     else if (COMPARE("hinting-range-max"))
@@ -322,6 +353,22 @@ TTF_autohint(const char* options,
   if (dehint)
     goto No_check;
 
+  if (gray_stem_width_mode < -1 || gray_stem_width_mode > 1)
+  {
+    error = FT_Err_Invalid_Argument;
+    goto Err1;
+  }
+  if (gdi_cleartype_stem_width_mode < -1 || gdi_cleartype_stem_width_mode > 1)
+  {
+    error = FT_Err_Invalid_Argument;
+    goto Err1;
+  }
+  if (dw_cleartype_stem_width_mode < -1 || dw_cleartype_stem_width_mode > 1)
+  {
+    error = FT_Err_Invalid_Argument;
+    goto Err1;
+  }
+
   if (hinting_range_min >= 0 && hinting_range_min < 2)
   {
     error = FT_Err_Invalid_Argument;
@@ -421,9 +468,9 @@ TTF_autohint(const char* options,
   font->x_height_snapping_exceptions = x_height_snapping_exceptions;
   font->fallback_stem_width = (FT_UInt)fallback_stem_width;
 
-  font->gray_strong_stem_width = gray_strong_stem_width;
-  font->gdi_cleartype_strong_stem_width = gdi_cleartype_strong_stem_width;
-  font->dw_cleartype_strong_stem_width = dw_cleartype_strong_stem_width;
+  font->gray_stem_width_mode = gray_stem_width_mode;
+  font->gdi_cleartype_stem_width_mode = gdi_cleartype_stem_width_mode;
+  font->dw_cleartype_stem_width_mode = dw_cleartype_stem_width_mode;
 
   font->windows_compatibility = windows_compatibility;
   font->ignore_restrictions = ignore_restrictions;
@@ -435,6 +482,9 @@ TTF_autohint(const char* options,
   font->symbol = symbol;
 
 No_check:
+  font->allocate = (allocate && out_bufp) ? allocate : malloc;
+  font->deallocate = (deallocate && out_bufp) ? deallocate : free;
+
   font->progress = progress;
   font->progress_data = progress_data;
   font->info = info;
